Connected habitat patch areas for Blue-tongued Lizard
Source:R/data-lizard-connected.R
lizard_areas_connected.RdPre-computed output of habitat_connectivity() run on the lizard example
data at a 50 metre interpatch distance. Contains one row per connected
habitat patch.
Format
A data frame with columns:
- patch_id
Integer. Connected fragment ID.
- area
Numeric. Total area of the connected patch in square metres.
An object of class patch_connectivity (inherits from tbl_df, tbl, data.frame) with 73 rows and 2 columns.
Generated from example_habitat() and example_barrier() at
50 metre interpatch distance.
Examples
# This was the code that was run to create this object. We don't run it
# as it takes some time to run
if (FALSE) { # \dontrun{
lizard_areas_connected <- habitat_connectivity(
habitat = example_habitat(),
barrier = example_barrier(),
species = "Blue-tongued Lizard",
interpatch_distance = 50,
verbose = FALSE
)
} # }
lizard_areas_connected
#> # patch_connectivity: data.frame
#> # Species: Blue-tongued Lizard
#> # Patches: 73
#> # Resolution: 2x2
#> # Interpatch Distance: 50 m
#> patch_id area
#> <dbl> <dbl>
#> 1 1 172.
#> 2 2 1592.
#> 3 7 98006.
#> 4 9 2416.
#> 5 10 1304.
#> # ℹ 68 more rows